starcluster.templates.user_msgs

Package starcluster :: Package templates :: Module user_msgs |
[hide private]
[frames] | no frames]

# Source Code for Module starcluster.templates.user_msgs

      1  #!/usr/bin/env python
      2
      3  active_ebs_cluster = """EBS Cluster '%(cluster_name)s' already exists.
      4
      5  Either choose a different tag name, or stop the EBS cluster using:
      6
      7      $ starcluster stop %(cluster_name)s
      8
      9  This command will put all nodes into a 'stopped' state and preserve their \
     10  local disks. The cluster can later be resumed by passing the -x option to \
     11  the start command. Another option is to terminate the existing EBS Cluster \
     12  using:
     13
     14      $ starcluster terminate %(cluster_name)s
     15
     16  NOTE: Terminating an EBS cluster will destroy the local disks (volumes) \
     17  backing the nodes.
     18  """
     19
     20  stopped_ebs_cluster = """Stopped EBS Cluster '%(cluster_name)s' already exists.
     21
     22  Either choose a different tag name, or start the stopped EBS cluster using:
     23
     24      $ starcluster start -x %(cluster_name)s
     25
     26  Another option is to terminate the existing EBS Cluster using:
     27
     28      $ starcluster terminate %(cluster_name)s
     29
     30  NOTE: Terminating an EBS cluster will destroy the local disks (volumes) \
     31  backing the nodes.
     32  """
     33
     34  cluster_exists = """Cluster with tag name %(cluster_name)s already exists.
     35
     36  If the cluster is a 'stopped' EBS cluster that you wish to 'start' or if you \
     37  have yet to configure the existing cluster nodes, pass the -x option to the \
     38  start command:
     39
     40      $ starcluster start -x %(cluster_name)s
     41
     42  If you wish to reconfigure the existing instances use the 'restart' command:
     43
     44      $ starcluster restart %(cluster_name)s
     45
     46  This will reboot all of the instances and configure the cluster starting from \
     47  scratch.
     48
     49  Otherwise either choose a different tag name, or terminate the existing \
     50  cluster using:
     51
     52      $ starcluster terminate %(cluster_name)s
     53
     54  """
     55
     56  cluster_started_msg = """
     57  The cluster is now ready to use. To login to the master node as \
     58  root, run:
     59
     60      $ starcluster sshmaster %(tag)s
     61
     62  When you are finished using the cluster and wish to terminate it and stop \
     63  paying for service:
     64
     65      $ starcluster terminate %(tag)s
     66
     67  NOTE: Terminating an EBS cluster will destroy all EBS volumes backing the \
     68  nodes.
     69
     70  Alternatively, if the cluster uses EBS instances, you can use the 'stop' \
     71  command to put all nodes into a 'stopped' state:
     72
     73      $ starcluster stop %(tag)s
     74
     75  NOTE: Any data stored in ephemeral storage (usually /mnt) will be lost!
     76
     77  This will shutdown all nodes in the cluster and put them in a 'stopped' state \
     78  that preserves the EBS volumes backing the nodes. A 'stopped' cluster may \
     79  then be restarted at a later time, without losing data on the local disks, by \
     80  passing the -x option to the 'start' command:
     81
     82      $ starcluster start -x %(tag)s
     83
     84  This will start all 'stopped' EBS instances and reconfigure the cluster.
     85
     86  """
     87
     88  spotmsg = """SPOT INSTANCES ARE NOT GUARANTEED TO COME UP
     89
     90  Spot instances can take a long time to come up and may not come up at all \
     91  depending on the current AWS load and your max spot bid price.
     92
     93  StarCluster will wait indefinitely until all instances (%(size)s) come up. \
     94  If this takes too long, you can cancel the start command using CTRL-C. \
     95  You can then resume the start command later on using the --no-create (-x) \
     96  option:
     97
     98      $ starcluster start -x %(tag)s
     99
    100  This will use the existing spot instances launched previously and continue \
    101  starting the cluster. If you don't wish to wait on the cluster any longer \
    102  after pressing CTRL-C simply terminate the cluster using the 'terminate' \
    103  command.\
    104  """
    105
    106  version_mismatch = """\
    107  The cluster '%(cluster)s' was created with a newer version of StarCluster \
    108  (%(new_version)s). You're currently using version %(old_version)s.
    109
    110  This may or may not be a problem depending on what's changed between these \
    111  versions, however, it's highly recommended that you use version \
    112  %(old_version)s when using the '%(cluster)s' cluster.\
    113  """
    114